summaryrefslogtreecommitdiffstats
path: root/kwin4/kwin4/kspritecache.h
diff options
context:
space:
mode:
Diffstat (limited to 'kwin4/kwin4/kspritecache.h')
-rw-r--r--kwin4/kwin4/kspritecache.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kwin4/kwin4/kspritecache.h b/kwin4/kwin4/kspritecache.h
index 94cb83d9..5a17a8ba 100644
--- a/kwin4/kwin4/kspritecache.h
+++ b/kwin4/kwin4/kspritecache.h
@@ -37,7 +37,7 @@ class KSprite;
public:
KSpriteNotify() :TQObject(0,0) {mRefCnt=0;}
- void emitSignal(TQCanvasItem *tqparent,int mode) {emit signalNotify(tqparent,mode);}
+ void emitSignal(TQCanvasItem *parent,int mode) {emit signalNotify(parent,mode);}
void incRefCnt() {mRefCnt++;}
void decRefCnt() {mRefCnt--;}
int refCnt() {return mRefCnt;}
@@ -147,7 +147,7 @@ class KSprite : public TQCanvasSprite
/**
* Creates a notification object. You can connect to it and it will emit
* the signal signalNotify(TQCanvasItem *tqparent, intmode) when a move or
* animation is finished.
* Example:
* <pre>
@@ -244,17 +244,17 @@ class KSprite : public TQCanvasSprite
*
* Example:
* <pre>
* # Sprite with three frames and a common tqmask for them
* # z position given but x,y set manually in the program
* [arrow]
* file=arrow%d.png
- * tqmask=arrow_tqmask.png
+ * mask=arrow_mask.png
* number=3
* offset=19,5
* rtti=32
* z=9.0
*
* # Simple sprite which is already positioned correcly. No tqmask just one file
* [board]
* file=board.png
* rtti=32
@@ -267,7 +267,7 @@ class KSprite : public TQCanvasSprite
* [star]
* anim0=0,4,2,8
* file=star%d.png
- * tqmask=star%d_tqmask.png
+ * mask=star%d_mask.png
* number=5
* offset=19,20
* rtti=32
@@ -293,7 +293,7 @@ class KSpriteCache : public TQObject
*
* @param grafixdir - the directory where the configuration file and the graphics reside
**/
- KSpriteCache(TQString grafixdir, TQObject* tqparent=0,const char * name=0);
+ KSpriteCache(TQString grafixdir, TQObject* parent=0,const char * name=0);
/**
* Delete the sprite cache
@@ -369,10 +369,10 @@ class KSpriteCache : public TQObject
/**
* This function loads a pixmap from the given file. Optional you can also
* provide a tqmask file. Also optinal you can provide the directory. Default
* is the directory which is set with this @ref KSpriteCache
**/
- TQPixmap * loadPixmap(TQString file,TQString tqmask=TQString(),TQString dir=TQString());
+ TQPixmap * loadPixmap(TQString file,TQString mask=TQString(),TQString dir=TQString());
/**
* Deletes a item form the sprite cache given as a pointer to it
@@ -438,7 +438,7 @@ class KSpriteCache : public TQObject
* number=(int) : how many frames to generate
* file=(Qstring) : the filename to load (can contain printf format args
* as %d which are replaced, e.g. file=hello_%d.png
- * tqmask=(TQString) : Same for the tqmask of the pixmaps
+ * mask=(TQString) : Same for the mask of the pixmaps
* axis=(int) : (scale only): scale axis (1=x,2=y,3=x+y)
* final=(double) : final scale in percent (default 0.0, i.e. complete scaling)
* colorfilter=1,h,s,v: make a HSV transform of all sprite images
@@ -147,7 +147,7 @@ class KSprite : public TQCanvasSprite
/**
* Creates a notification object. You can connect to it and it will emit
- * the signal signalNotify(TQCanvasItem *tqparent, intmode) when a move or
+ * the signal signalNotify(TQCanvasItem *parent, intmode) when a move or
* animation is finished.
* Example:
@@ -244,17 +244,17 @@ class KSprite : public TQCanvasSprite
* Example:
* <pre>
- * # Sprite with three frames and a common tqmask for them
+ * # Sprite with three frames and a common mask for them
* # z position given but x,y set manually in the program
* [arrow]
@@ -244,17 +244,17 @@ class KSprite : public TQCanvasSprite
* z=9.0
*
- * # Simple sprite which is already positioned correcly. No tqmask just one file
+ * # Simple sprite which is already positioned correcly. No mask just one file
* [board]
* file=board.png
@@ -369,10 +369,10 @@ class KSpriteCache : public TQObject
/**
* This function loads a pixmap from the given file. Optional you can also
- * provide a tqmask file. Also optinal you can provide the directory. Default
+ * provide a mask file. Also optinal you can provide the directory. Default
* is the directory which is set with this @ref KSpriteCache
**/